Stan Math Library: stan/math/prim/scal/prob/exp_mod_normal_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exp_mod_normal_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_EXP_MOD_NORMAL_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_EXP_MOD_NORMAL_RNG_HPP
3
4 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
5 #include <stan/math/prim/scal/err/check_finite.hpp>
6 #include <stan/math/prim/scal/err/check_not_nan.hpp>
7 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
8 #include <stan/math/prim/scal/fun/constants.hpp>
9 #include <stan/math/prim/scal/meta/length.hpp>
10 #include <stan/math/prim/scal/meta/VectorView.hpp>
11 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
12 #include <stan/math/prim/scal/prob/normal_rng.hpp>
13 #include <stan/math/prim/scal/prob/exponential_rng.hpp>
14 #include <stan/math/prim/scal/meta/include_summand.hpp>
15 #include <stan/math/prim/scal/fun/value_of.hpp>
16 #include <boost/random/normal_distribution.hpp>
17 #include <boost/math/special_functions/fpclassify.hpp>
18 #include <boost/random/variate_generator.hpp>
19
20 namespace stan {
21
22 namespace math {
23
24 template <class RNG>
25 inline double
26 exp_mod_normal_rng(const double mu,
27 const double sigma,
28 const double lambda,
29 RNG& rng) {
30 static const char* function("stan::math::exp_mod_normal_rng");
31
32 using stan::math::check_positive_finite;
33 using stan::math::check_finite;
34
35 check_finite(function, "Location parameter", mu);
36 check_positive_finite(function, "Inv_scale parameter", lambda);
37 check_positive_finite(function, "Scale parameter", sigma);
38
39 return stan::math::normal_rng(mu, sigma, rng)
40 + stan::math::exponential_rng(lambda, rng);
41 }
42 }
43 }
44 #endif
45
46
47
check_not_nan.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
exponential_rng.hpp
normal_rng.hpp
stan::math::exponential_rng
double exponential_rng(const double beta, RNG &rng)
Definition: exponential_rng.hpp:24
include_summand.hpp
stan::math::exp_mod_normal_rng
double exp_mod_normal_rng(const double mu, const double sigma, const double lambda, RNG &rng)
Definition: exp_mod_normal_rng.hpp:26
VectorView.hpp
VectorBuilder.hpp
length.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
value_of.hpp
stan::math::normal_rng
double normal_rng(const double mu, const double sigma, RNG &rng)
Definition: normal_rng.hpp:19
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.